*cd \workingdirectory\ /**<- Change this to the directory of the raw data file **/

cd "/Users/evanstarr/Documents/Locked In LEHD?/JHR Accepted/Replication/Replication Outpus/" 
/****/
/**
https://lehd.ces.census.gov/data/schema/latest/lehd_public_use_schema.html#_national_qwi_and_state_level_qwi_qwipu
**/

global csif "if edcode ==0 & tech==1"
global wsif "if edcode ==0 & hi==1"
global csdum hi
global wsdum tech
global csclust statecode
global wsclust ind
global dddclust statecode

global csdes "Cross-State, Within-Tech"
global wsdes "Within-Hawaii, Cross-Industry"
global ddddes "Triple Difference Analysis"

global wsdd Tech
global csdd Hawaii
global ddddd Hawaii


global abws "i.ind i.yrqtr"
global abcs "i.ind##i.yrqtr i.statecode##i.ind"


/************************************************************************************/
/********Setup for binscatter analysis ***************/
/************************************************************************************/
foreach yy in ws cs {
	use sepr sepbegr earns earnhiras emp emptotal emps yrqtr statecode edcode industry w hi tech dfhi ///
		Tech2d geography stateXtech using temp_qwi_fin ${`yy'if}, clear
	gen old_$`yy'clust=$`yy'clust
	replace $`yy'clust=0 if ${`yy'dum}==1 /*** To make the treated industry/state as group =0 ***/
	foreach xx in sepr sepbegr earns earnhiras  emp emptotal emps {
		local lab`xx': variable label `xx'
	}

	collapse (first) dfhi  geography (mean) old_${`yy'clust} w ///
		Tech2d hi tech  sepr sepbegr earns earnhiras emp emptotal emps [aw=w], ///
		by(${`yy'clust} yrqtr)
		
		foreach xx in sepr sepbegr earns earnhiras  emp emps emptotal {
			label var `xx' "`lab`xx''"
		}
	gen ln_earns=log(earns)
	gen ln_earnhiras=log(earnhiras)
	gen ln_emp=log(emp)
	gen ln_emptotal=log(emptotal)
	gen ln_emps=log(emps)
	label var ln_emp "Log `labemp' "
	label var ln_emptotal "Log `labemptotal'"
	label var ln_emps "Log `labemps'"
	label var ln_earns " Log `labearns'"
	label var ln_earnhiras " Log `labearnhiras'"

	egen grtreat=group(${`yy'clust})
	tsset grtreat yrqtr
	egen ct=count(yrqtr), by(grtreat)
	keep if ct==16
	format yrqtr %tq
	xtdes
	label var sepr "Overall Separation Rate"
	label var sepbegr "Beginning-of-Quarter Separation Rate"
	label var ln_earns "Log Overall Avg Monthly Earnings" 
	label var ln_earnhiras "Log Hires Avg Monthly Earnings" 
	label var ln_emp "Log Beginning-of-Quarter Employment"
	label var ln_emptotal "Log Employment-Reference Quarter"
	
save temp_qwi_synth_`yy', replace
}


/************************************************************/
/*** Binscatter analysis -- **/
/************************************************************/
ssc install binscatter, replace 

foreach yy in ws cs {
	use temp_qwi_synth_`yy' , clear 
		foreach xx in ln_earns ln_earnhiras sepr sepbegr {
			local lab: variable label `xx'  /* <- save variable label in local `lab'*/
			binscatter `xx' yrqtr [aw=w], n(16) absorb(${`yy'clust}) by(${`yy'dum})  ///
			m(o Th  Sh ) legend( lab(1 "Other") ///
			lab(2 "${`yy'dd}") rows(1) size(small)) rd(221.1) ///
			line(connect) xlabel(213(3)228,format(%tq) labsize(small)) xtitle("")  ytitle("")  ///
			t2("`lab'", size(small)) title("${`yy'des}", size(small)) ///
	savegraph(qwi_bs_`yy'_collwtd_`xx'.gph)
}
}

/** Figure 1 ******/
**QWI Earnings Variables: Binned Scatter Plots
graph combine qwi_bs_ws_collwtd_ln_earns.gph qwi_bs_ws_collwtd_ln_earnhiras.gph ///
	qwi_bs_cs_collwtd_ln_earns.gph qwi_bs_cs_collwtd_ln_earnhiras.gph , ///
	saving(Figure1_qwi_bs_earn_collwtd_all.gph, replace) graphregion(color(white)) ///
	title("QWI Earnings Trends", size(small))
graph save "Figure1_qwi_bs_earn_collwtd_all.gph", replace
graph export "Figure1_qwi_bs_earn_collwtd_all.png", as(png) replace

/** Figure 2 ******/
**QWI Mobility Variables: Binned Scatter Plots
graph combine qwi_bs_ws_collwtd_sepr.gph qwi_bs_ws_collwtd_sepbegr.gph ///
	qwi_bs_cs_collwtd_sepr.gph qwi_bs_cs_collwtd_sepbegr.gph , ///
	saving(Figure2_qwi_bs_mob_collwtd_all.gph, replace) graphregion(color(white)) ///
	title("QWI Mobility Trends", size(small))
graph save "Figure2_qwi_bs_mob_collwtd_all.gph",  replace
graph export "Figure2_qwi_bs_mob_collwtd_all.png", as(png) replace

/*************************************************************/
**Tables 1 and 2: DID Analysis
/*************************************************************/
ssc install outreg2, replace
ssc install reghdfe, replace
ssc install ftools, replace


/*************************************************************/
/** First -Cross-industry within Hawaii**/
/*************************************************************/
capture program drop myregs_within_hi
program define myregs_within_hi
use temp_qwi_fin if edcode==0 & hi==1, clear 
ren industry ind
gen postXtech=post*tech
gen srpostXtech=srpost*tech
gen lrpostXtech=lrpost*tech
global interws1 postXtech
global interws2 srpostXtech lrpostXtech
global out outreg2 using "`2'.xls",
local replace replace
foreach y in  ${`1'} {
foreach sample in Tech2d All {
foreach int in interws1 interws2 {
reghdfe `y' ${`int'} if `sample'==1 [aw=EmpWgt], cl(ind) absorb(i.ind i.yrqtr) 
$out  `replace' ctitle(`y') addtext(Industry FE, Yes, Quarter FE, Yes, Sample, `sample', ///
Weights, EmpWgt, DV, `y', SE Clustered By, Industry)
local replace
}
}
}
end

/*************************************************************/
/** Next -Cross-state within Tech**/
/*************************************************************/
capture program drop myregs_within_tech
program define myregs_within_tech 
use temp_qwi_fin if edcode==0 & tech==1, clear 
ren industry ind
gen postXhi=post*hi
gen srpostXhi=srpost*hi
gen lrpostXhi=lrpost*hi
global intercs1 postXhi
global intercs2 srpostXhi lrpostXhi
global out outreg2 using "`2'.xls",
local replace replace
foreach y in  ${`1'} {
foreach sample in dfhi40 dfhi50  {
foreach int in intercs1 intercs2 {
reghdfe `y' ${`int'} if `sample'==1 [aw=EmpWgt ], cl(statecode) absorb(i.ind##i.yrqtr i.statecode##i.ind) 
$out `replace' ctitle(`y') addtext(Sample, `sample', Weights, EmpWgt , DV, `y', SE Clustered By, State, Ind X Qtr, Yes,  State X Ind, Yes )
local replace
}
}
}
end 
/*************************************************************/
global lnevars ln_earns ln_earnhiras 
global mobvars sepr sepbegr

myregs_within_hi lnevars Table1_panelA_QWI_DID   
myregs_within_tech lnevars Table1_panelB_QWI_DID
   
myregs_within_hi mobvars Table2_panelA_QWI_DID   
myregs_within_tech mobvars Table2_panelB_QWI_DID

/***********************************************/
/***Table 3 DDD Analysis****************/
/***********************************************/
global out outreg2 using "Table3_QWI_DDD.xls",
local replace replace
use temp_qwi_fin if edcode==0,  clear /**Keeps all workers**/ 
foreach hh in post srpost lrpost {
gen `hh'XhiXtech=`hh'*hi*tech
gen `hh'Xhi=`hh'*hi
gen `hh'Xtech=`hh'*tech
}
gen hiXtech=hi*tech
/** With Ind X Year-Qtr FE, State X Ind and State X Year-Qtr Fixed effects, only the following inetractions are identified (verified that all other direct terms and interactions are absorbed by the fixed effects) **/ 
global interddd1_sh postXhiXtech 
global interddd2_sh srpostXhiXtech lrpostXhiXtech

ren industry ind
foreach y in   ln_earns ln_earnhiras sepr sepbegr {
foreach sample in dfhi40 dfhi50  {
foreach int in interddd1_sh interddd2_sh {
foreach wt in EmpWgt {
reghdfe `y' ${`int'} if `sample'==1 [aw=`wt'], cl(statecode) absorb(indyrqtr stateyrqtr stateind) 
$out `replace' ctitle(`y') addtext(Industry FE, NA, Quarter FE, NA, Sample, `sample', ///
Weights, `wt', DV, `y', SE Clustered By, State, State FE, NA, Ind X Qtr, Yes,  State X Ind, Yes, State X Qtr, Yes )
local replace 
}
}
}
}

/***********************************************/
/***Appendix Table 1 ****************/
/***********************************************/
global ddhi HI_tech
global ddtech tech_HI
global ffhi tech
global fftech hi
foreach yy in hi tech {
foreach xx in emp  hirn sep {
use temp_qwi_fin if edcode ==0 & `yy'==1, clear 
gen yr_qtr=year*100+quarter
drop if yr_qtr==201702
collapse (mean) post (sum) `xx', by(yr_qtr ${ff`yy'})
collapse (mean) `xx', by(post ${ff`yy'})
reshape wide `xx', i(post) j(${ff`yy'})
renpfix `xx' ${dd`yy'}
gen str10 var="`xx'" 
order var
tempfile t`xx'
save `t`xx''
}
use `temp', clear
append using `thirn'
append using `tsep'
gen total_`yy'=${dd`yy'}0+ ${dd`yy'}1
replace ${dd`yy'}0=round(${dd`yy'}0,1)
replace ${dd`yy'}1=round(${dd`yy'}1,1)
replace total=round(total,1)
sort var post
tempfile temp_`yy'
save `temp_`yy'', replace
}
use `temp_hi'
merge 1:1 var post using `temp_tech'
drop _m
export excel using Appendix_Table1.xls, replace



